@@ -1,7 +1,8 @@
 import pandas as pd
+
 from .api_client import ApiClient
 from .models import (
-    TestViewRequest,
+    TestAttributeGroupRequest,
 )
 
 
@@ -9,10 +10,10 @@ class TestingClient:
     def __init__(self, api_client: ApiClient):
         self.api_client = api_client
 
-    def test_view(self, request: TestViewRequest) -> pd.DataFrame:
+    def test_view(self, request: TestAttributeGroupRequest) -> pd.DataFrame:
         data = self.api_client.make_request(
             method="POST",
-            endpoint="testing/views/",
+            endpoint="testing/attribute_groups/",
             data=request.model_dump(
                 mode="json",
                 exclude_none=True,
